@@ -6,7 +6,8 @@ import packaging.version
 
 from core_changelog_md.common.enums import ChangeTypes
 from core_changelog_md.common.exceptions import UnCorrectTitleException, \
-    MissedVersionsSymbolException, VersionOverTextException, NotDetectVersionException, VersionDateConvertException
+    MissedVersionsSymbolException, VersionOverTextException, NotDetectVersionException, VersionDateConvertException, \
+    UnDetectLine
 from core_changelog_md.exceptions import VersionNotFoundException
 from core_changelog_md.objects.changes import ChangeCollection, ChangeBlock
 from core_changelog_md.objects.version import VersionCollection, VersionBlock
@@ -102,14 +103,17 @@ class Changelog(object):
         """
 
         # Первая строчка должна быть именем
-        clean_data = [item.strip() for item in data_string.replace("---", '').split('\n') if item.strip()]
+        clean_data = [item.strip() for item in data_string.replace("---", '').split('\n')]
         obj = cls(name=Changelog.check_name(clean_data[0]))
         clean_data = clean_data[1:]
 
         # Разбиваем на версии
-        for item in clean_data:
+        for index, item in enumerate(clean_data):
+            # Пропускаем пустые строчки
+            if not item.strip():
+                continue
             # Старт обработки новой версии
-            if item.strip().startswith("##") and not item.strip().startswith("###"):
+            elif item.strip().startswith("##") and not item.strip().startswith("###"):
                 version_name = Changelog.check_version_name(version_name=item)
                 obj.versions.append(VersionBlock(
                     version=version_name,
@@ -128,7 +132,12 @@ class Changelog(object):
                 obj.versions.get_by_name(version_name=version_name) \
                     .change_blocks[change_tag].changes.append(item.strip()[1:].strip())
             else:
-                raise NotImplementedError
+                raise UnDetectLine(
+                    f'Cant detect line "{item}" in line {index + 2}\n'
+                    f'Version must started by ##\n'
+                    f'ChangeBlock must started by #\n'
+                    f'Changes must started by "-"'
+                )
         return obj
 
     @property
@@ -137,7 +146,7 @@ class Changelog(object):
         Возвращает текущую версию Changelog
         """
         if len(self.versions) > 1:
-            return max(list(self.versions)[1:])
+            return max(list(self.versions)[1:]) if self.unreleased else max(list(self.versions))
         return self.unreleased
 
     @property
